@@ -2,15 +2,15 @@ from __future__ import annotations
 
 from typing import Sequence
 
-from pre_commit.languages import helpers
+from pre_commit import lang_base
 from pre_commit.languages.docker import docker_cmd
 from pre_commit.prefix import Prefix
 
 ENVIRONMENT_DIR = None
-get_default_version = helpers.basic_get_default_version
-health_check = helpers.basic_health_check
-install_environment = helpers.no_install
-in_env = helpers.no_env
+get_default_version = lang_base.basic_get_default_version
+health_check = lang_base.basic_health_check
+install_environment = lang_base.no_install
+in_env = lang_base.no_env
 
 
 def run_hook(
@@ -19,11 +19,12 @@ def run_hook(
         args: Sequence[str],
         file_args: Sequence[str],
         *,
+        is_local: bool,
         require_serial: bool,
         color: bool,
 ) -> tuple[int, bytes]:  # pragma: win32 no cover
-    cmd = docker_cmd() + helpers.hook_cmd(entry, args)
-    return helpers.run_xargs(
+    cmd = docker_cmd() + lang_base.hook_cmd(entry, args)
+    return lang_base.run_xargs(
         cmd,
         file_args,
         require_serial=require_serial,
